@@ -36,25 +36,16 @@ import orca.settings
 
 formatting = {
     'speech': {
-        # Get rid of unselectedCell because we don't run into that in OOo
-        # and we'd end up always speaking "not selected" for all table cells.
-        #
-        'suffix': {
-            'focused': '[]',
-            'unfocused': 'newNodeLevel + ' + orca.formatting.TUTORIAL,
-            'basicWhereAmI': orca.formatting.TUTORIAL + ' + description',
-            'detailedWhereAmI' : '[]'
-            },
         pyatspi.ROLE_LABEL: {
             'focused': 'expandableState + availability',
             'unfocused': 'name + allTextSelection + expandableState + availability + positionInList',
             'basicWhereAmI': 'roleName + name + positionInList + expandableState + (nodeLevel or nestingLevel)'
             },
         pyatspi.ROLE_TABLE_CELL: {
-            'focused': 'endOfTableIndicator + tableCellRow',
-            'unfocused': 'endOfTableIndicator + tableCellRow',
-            'basicWhereAmI': 'parentRoleName + columnHeader + rowHeader + roleName + cellCheckedState + (realActiveDescendantDisplayedText or imageDescription + image) + columnAndRow + expandableState + nodeLevel',
-            'detailedWhereAmI': 'parentRoleName + columnHeader + rowHeader + roleName + cellCheckedState + (realActiveDescendantDisplayedText or imageDescription + image) + columnAndRow + tableCellRow + expandableState + nodeLevel'
+            'focused': 'endOfTableIndicator + pause + tableCellRow + pause',
+            'unfocused': 'endOfTableIndicator + pause + tableCellRow + pause',
+            'basicWhereAmI': 'parentRoleName + pause + columnHeader + pause + rowHeader + pause + roleName + pause + cellCheckedState + pause + (realActiveDescendantDisplayedText or imageDescription + image) + pause + columnAndRow + pause + expandableState + pause + nodeLevel + pause',
+            'detailedWhereAmI': 'parentRoleName + pause + columnHeader + pause + rowHeader + pause + roleName + pause + cellCheckedState + pause + (realActiveDescendantDisplayedText or imageDescription + image) + pause + columnAndRow + pause + tableCellRow + pause + expandableState + pause + nodeLevel + pause'
             },
         'REAL_ROLE_TABLE_CELL': {
             'focused': 'newRowHeader + newColumnHeader + realActiveDescendantDisplayedText',
@@ -64,7 +55,7 @@ formatting = {
             # We treat spreadsheet cells differently from other table cells in
             # whereAmI.
             #
-            'basicWhereAmI': 'roleName + column + columnHeader + row + rowHeader + (textContent or realTableCell) + anyTextSelection'
+            'basicWhereAmI': 'roleName + pause + column + pause + columnHeader + pause + row + pause + rowHeader + pause + (textContent or realTableCell) + pause + anyTextSelection + pause'
             },
     },
     'braille': {
@@ -80,18 +71,6 @@ formatting = {
     }
 }
 
-if orca.settings.useExperimentalSpeechProsody:
-    formatting['speech']['ROLE_SPREADSHEET_CELL']['basicWhereAmI'] = \
-        'roleName + pause + column + pause + columnHeader + pause + row + pause + rowHeader + pause + (textContent or realTableCell) + pause + anyTextSelection + pause'
-    formatting['speech'][pyatspi.ROLE_TABLE_CELL]['focused'] = \
-        'endOfTableIndicator + pause + tableCellRow + pause'
-    formatting['speech'][pyatspi.ROLE_TABLE_CELL]['unfocused'] = \
-        'endOfTableIndicator + pause + tableCellRow + pause'
-    formatting['speech'][pyatspi.ROLE_TABLE_CELL]['basicWhereAmI'] = \
-        'parentRoleName + pause + columnHeader + pause + rowHeader + pause + roleName + pause + cellCheckedState + pause + (realActiveDescendantDisplayedText or imageDescription + image) + pause + columnAndRow + pause + expandableState + pause + nodeLevel + pause'
-    formatting['speech'][pyatspi.ROLE_TABLE_CELL]['detailedWhereAmI'] = \
-        'parentRoleName + pause + columnHeader + pause + rowHeader + pause + roleName + pause + cellCheckedState + pause + (realActiveDescendantDisplayedText or imageDescription + image) + pause + columnAndRow + pause + tableCellRow + pause + expandableState + pause + nodeLevel + pause'
-
 class Formatting(orca.formatting.Formatting):
     def __init__(self, script):
         orca.formatting.Formatting.__init__(self, script)
